==> huaweicloudsdkcloudtest-3.1.110-py2.py3-none-any.whl: huaweicloudsdkcloudtest/v1/model/list_basic_aw_info_list_supports_search_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListBasicAwInfoListSupportsSearchRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'project_id': 'str',
        'page_no': 'str',
        'page_size': 'str',
        'parent_id': 'str',
        'body': 'SearchRequest'
    }

    attribute_map = {
        'project_id': 'project_id',
        'page_no': 'page_no',
        'page_size': 'page_size',
        'parent_id': 'parent_id',
        'body': 'body'
    }

    def __init__(self, project_id=None, page_no=None, page_size=None, parent_id=None, body=None):
        """ListBasicAwInfoListSupportsSearchRequest

        The model defined in huaweicloud sdk

        :param project_id: 项目ID，固定长度32位字符（字母和数字）。
        :type project_id: str
        :param page_no: 当前页数
        :type page_no: str
        :param page_size: 每页多少记录
        :type page_size: str
        :param parent_id: 父目录ID
        :type parent_id: str
        :param body: Body of the ListBasicAwInfoListSupportsSearchRequest
        :type body: :class:`huaweicloudsdkcloudtest.v1.SearchRequest`
        """
        
        

        self._project_id = None
        self._page_no = None
        self._page_size = None
        self._parent_id = None
        self._body = None
        self.discriminator = None

        self.project_id = project_id
        self.page_no = page_no
        self.page_size = page_size
        if parent_id is not None:
            self.parent_id = parent_id
        if body is not None:
            self.body = body

    @property
    def project_id(self):
        """Gets the project_id of this ListBasicAwInfoListSupportsSearchRequest.

        项目ID，固定长度32位字符（字母和数字）。

        :return: The project_id of this ListBasicAwInfoListSupportsSearchRequest.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this ListBasicAwInfoListSupportsSearchRequest.

        项目ID，固定长度32位字符（字母和数字）。

        :param project_id: The project_id of this ListBasicAwInfoListSupportsSearchRequest.
        :type project_id: str
        """
        self._project_id = project_id

    @property
    def page_no(self):
        """Gets the page_no of this ListBasicAwInfoListSupportsSearchRequest.

        当前页数

        :return: The page_no of this ListBasicAwInfoListSupportsSearchRequest.
        :rtype: str
        """
        return self._page_no

    @page_no.setter
    def page_no(self, page_no):
        """Sets the page_no of this ListBasicAwInfoListSupportsSearchRequest.

        当前页数

        :param page_no: The page_no of this ListBasicAwInfoListSupportsSearchRequest.
        :type page_no: str
        """
        self._page_no = page_no

    @property
    def page_size(self):
        """Gets the page_size of this ListBasicAwInfoListSupportsSearchRequest.

        每页多少记录

        :return: The page_size of this ListBasicAwInfoListSupportsSearchRequest.
        :rtype: str
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """Sets the page_size of this ListBasicAwInfoListSupportsSearchRequest.

        每页多少记录

        :param page_size: The page_size of this ListBasicAwInfoListSupportsSearchRequest.
        :type page_size: str
        """
        self._page_size = page_size

    @property
    def parent_id(self):
        """Gets the parent_id of this ListBasicAwInfoListSupportsSearchRequest.

        父目录ID

        :return: The parent_id of this ListBasicAwInfoListSupportsSearchRequest.
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        """Sets the parent_id of this ListBasicAwInfoListSupportsSearchRequest.

        父目录ID

        :param parent_id: The parent_id of this ListBasicAwInfoListSupportsSearchRequest.
        :type parent_id: str
        """
        self._parent_id = parent_id

    @property
    def body(self):
        """Gets the body of this ListBasicAwInfoListSupportsSearchRequest.

        :return: The body of this ListBasicAwInfoListSupportsSearchRequest.
        :rtype: :class:`huaweicloudsdkcloudtest.v1.SearchRequest`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ListBasicAwInfoListSupportsSearchRequest.

        :param body: The body of this ListBasicAwInfoListSupportsSearchRequest.
        :type body: :class:`huaweicloudsdkcloudtest.v1.SearchRequest`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListBasicAwInfoListSupportsSearchRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcloudtest-3.1.151-py2.py3-none-any.whl: huaweicloudsdkcloudtest/v1/model/list_basic_aw_info_list_supports_search_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListBasicAwInfoListSupportsSearchRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'project_id': 'str',
        'page_no': 'str',
        'page_size': 'str',
        'parent_id': 'str',
        'body': 'SearchRequest'
    }

    attribute_map = {
        'project_id': 'project_id',
        'page_no': 'page_no',
        'page_size': 'page_size',
        'parent_id': 'parent_id',
        'body': 'body'
    }

    def __init__(self, project_id=None, page_no=None, page_size=None, parent_id=None, body=None):
        r"""ListBasicAwInfoListSupportsSearchRequest

        The model defined in huaweicloud sdk

        :param project_id: 项目ID，固定长度32位字符（字母和数字）。
        :type project_id: str
        :param page_no: 当前页数
        :type page_no: str
        :param page_size: 每页多少记录
        :type page_size: str
        :param parent_id: 父目录ID
        :type parent_id: str
        :param body: Body of the ListBasicAwInfoListSupportsSearchRequest
        :type body: :class:`huaweicloudsdkcloudtest.v1.SearchRequest`
        """
        
        

        self._project_id = None
        self._page_no = None
        self._page_size = None
        self._parent_id = None
        self._body = None
        self.discriminator = None

        self.project_id = project_id
        self.page_no = page_no
        self.page_size = page_size
        if parent_id is not None:
            self.parent_id = parent_id
        if body is not None:
            self.body = body

    @property
    def project_id(self):
        r"""Gets the project_id of this ListBasicAwInfoListSupportsSearchRequest.

        项目ID，固定长度32位字符（字母和数字）。

        :return: The project_id of this ListBasicAwInfoListSupportsSearchRequest.
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        r"""Sets the project_id of this ListBasicAwInfoListSupportsSearchRequest.

        项目ID，固定长度32位字符（字母和数字）。

        :param project_id: The project_id of this ListBasicAwInfoListSupportsSearchRequest.
        :type project_id: str
        """
        self._project_id = project_id

    @property
    def page_no(self):
        r"""Gets the page_no of this ListBasicAwInfoListSupportsSearchRequest.

        当前页数

        :return: The page_no of this ListBasicAwInfoListSupportsSearchRequest.
        :rtype: str
        """
        return self._page_no

    @page_no.setter
    def page_no(self, page_no):
        r"""Sets the page_no of this ListBasicAwInfoListSupportsSearchRequest.

        当前页数

        :param page_no: The page_no of this ListBasicAwInfoListSupportsSearchRequest.
        :type page_no: str
        """
        self._page_no = page_no

    @property
    def page_size(self):
        r"""Gets the page_size of this ListBasicAwInfoListSupportsSearchRequest.

        每页多少记录

        :return: The page_size of this ListBasicAwInfoListSupportsSearchRequest.
        :rtype: str
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        r"""Sets the page_size of this ListBasicAwInfoListSupportsSearchRequest.

        每页多少记录

        :param page_size: The page_size of this ListBasicAwInfoListSupportsSearchRequest.
        :type page_size: str
        """
        self._page_size = page_size

    @property
    def parent_id(self):
        r"""Gets the parent_id of this ListBasicAwInfoListSupportsSearchRequest.

        父目录ID

        :return: The parent_id of this ListBasicAwInfoListSupportsSearchRequest.
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id):
        r"""Sets the parent_id of this ListBasicAwInfoListSupportsSearchRequest.

        父目录ID

        :param parent_id: The parent_id of this ListBasicAwInfoListSupportsSearchRequest.
        :type parent_id: str
        """
        self._parent_id = parent_id

    @property
    def body(self):
        r"""Gets the body of this ListBasicAwInfoListSupportsSearchRequest.

        :return: The body of this ListBasicAwInfoListSupportsSearchRequest.
        :rtype: :class:`huaweicloudsdkcloudtest.v1.SearchRequest`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this ListBasicAwInfoListSupportsSearchRequest.

        :param body: The body of this ListBasicAwInfoListSupportsSearchRequest.
        :type body: :class:`huaweicloudsdkcloudtest.v1.SearchRequest`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListBasicAwInfoListSupportsSearchRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
